==> cambridge-3.9.2-py3-none-any.whl: cambridge/color.py <==
COLOR_EFFECT = {
    "BLACK"         : "30",
    "RED"           : "31",
    "GREEN"         : "32",
    "YELLOW"        : "33",
    "BLUE"          : "34",
    "MAGENTA"       : "35",
    "CYAN"          : "36",
    "WHITE"         : "37",
    "RESET"         : "0",
    "BOLD"          : "1",
    "ITALIC"        : "3"
}

# Webster
accessory = "#4A7D95"
badge = "#E06C75"
or_badge = "#3AB0FF"

# 1. Webster dictionary-entry
# 1.1 entry-header-content
eh_h1_word = "#2E8B57"
eh_word_type = "#FD7E14"
eh_word_syllables = "#757575"
# eh_pron = "#4A7D95" # UNUSED

# 1.2 verb tenses, noun plurals, adjective comparative forms
# wt = "#525A5B" # UNUSED

# 1.3 other word forms
wf = "#4A7D95"
wf_type = "#4A7D95"

# 1.4 transitive / intransitive
# tran = "yellow" # UNUSED

# 1.5 one meaning of one entry
meaning_num = "#757575"
meaning_letter = "#757575"
meaning_link = "#4A7D95"
meaning_content = "#4A7D95"
meaning_badge = badge
meaning_arrow = "#8B5742"
meaning_keyword = "#3AB0FF"
meaning_sentence = "#757575"

### 1.6 dxnls
dxnls_title = "#2E8B57"
dxnls_content = "#757575"

# 2. Webster phrases
ph_title = "#2E8B57"
ph_item = "#4A7D95"

# 3. Webster synonyms
syn_title = "#0F3850"
syn_item = "#757575"
syn_em = "#2E8B57"
syn_label = "#0F3850"

# 4. Webster examples on the web
eg_title = "#0F3850"
eg_sentence = "#757575"
eg_word = "#2E8B57"

# 5. Webster related phrases
rph_title = "#0F3850"
rph_em = "#2E8B57"
rph_item = "#4A7D95"

# 6. Webster nearby entries
nearby_title = "#0F3850"
nearby_em = "#2E8B57"
nearby_word = "#757575"
nearby_item = "#4A7D95"

# 7. Webster dict name
dict_name = "#757575"

# 8. Webster Word of the Day
wod_title = "#2E8B57"
wod_type = eh_word_type
wod_syllables = eh_word_syllables
wod_subtitle = "#0F3850"
wod_sent = meaning_sentence

==> cambridge-3.11.3-py3-none-any.whl: cambridge/color.py <==
COLOR_EFFECT = {
    "BLACK"         : "30",
    "RED"           : "31",
    "GREEN"         : "32",
    "YELLOW"        : "33",
    "BLUE"          : "34",
    "MAGENTA"       : "35",
    "CYAN"          : "36",
    "WHITE"         : "37",
    "RESET"         : "0",
    "BOLD"          : "1",
    "ITALIC"        : "3"
}

# Webster
accessory = "#4A7D95"
badge = "#E06C75"
or_badge = "#757575"

# 1. Webster dictionary-entry
# 1.1 entry-header-content
eh_h1_word = "#2E8B57"
eh_word_type = "#FD7E14"
eh_word_syllables = "#757575"
# eh_pron = "#4A7D95" # UNUSED

# 1.2 verb tenses, noun plurals, adjective comparative forms
# wt = "#525A5B" # UNUSED

# 1.3 other word forms
wf = "#4A7D95"
wf_type = "#4A7D95"

# 1.4 transitive / intransitive
# tran = "yellow" # UNUSED

# 1.5 one meaning of one entry
meaning_num = "#757575"
meaning_letter = "#757575"
meaning_link = "#4A7D95"
meaning_content = "#4A7D95"
meaning_badge = badge
meaning_arrow = "#757575"
meaning_keyword = "#757575"
meaning_sentence = "#757575"

### 1.6 dxnls
dxnls_title = "#2E8B57"
dxnls_content = "#757575"

# 2. Webster phrases
ph_title = "#2E8B57"
ph_item = "#4A7D95"

# 3. Webster synonyms
syn_title = "#757575"
syn_item = "#4A7D95"
syn_em = "#2E8B57"
# syn_label = "#0F3850"
syn_label = "#757575"

# 4. Webster examples on the web
eg_title = syn_title
eg_sentence = "#757575"
eg_word = "#2E8B57"

# 5. Webster related phrases
rph_title = syn_title
rph_em = "#2E8B57"
rph_item = "#4A7D95"

# 6. Webster nearby entries
nearby_title = syn_title
nearby_em = "#2E8B57"
nearby_word = "#757575"
nearby_item = "#4A7D95"

# 7. Webster dict name
dict_name = "#757575"

# 8. Webster Word of the Day
wod_title = "#2E8B57"
wod_type = eh_word_type
wod_syllables = eh_word_syllables
wod_subtitle = syn_title
wod_sent = meaning_sentence
